
<!-- Edit README.md, not index.md -->

# papertlab is your AI coding buddy

papertlab lets you pair program with LLMs,
to edit code in your local git repository.
Start a new project or work with an existing git repo.
papertlab works best with Claude 3.5 Sonnet.